diff --git a/Code/Mantid/Framework/ScriptRepository/src/ScriptRepositoryImpl.cpp b/Code/Mantid/Framework/ScriptRepository/src/ScriptRepositoryImpl.cpp
index 7882622..08015e5 100644
--- a/Code/Mantid/Framework/ScriptRepository/src/ScriptRepositoryImpl.cpp
+++ b/Code/Mantid/Framework/ScriptRepository/src/ScriptRepositoryImpl.cpp
@@ -787,8 +787,8 @@ namespace API
       m_file->stream().seekg(0,std::ios::beg);  
       // set the size
       req.setContentLength((int)sst.str().size());
-      
-      std::ostream& ostr = session.sendRequest(req);
+
+      std::ostream & ostr = session.sendRequest(req); 
       // send the request.
       ostr << sst.str(); 
       
@@ -1034,6 +1034,13 @@ namespace API
                       HTTPMessage::HTTP_1_0); 
       g_log.debug() << "Receive request to delete file " << file_path << " using " << url << std::endl; 
 
+      // configure proxy
+      std::string proxy_config; 
+      unsigned short proxy_port; 
+      if (getProxyConfig(proxy_config, proxy_port))
+        session.setProxy(proxy_config, proxy_port);
+      // proxy end
+
 
       // fill up the form required from the server to delete one file, with the fields 
       // path, author, comment, email
@@ -1045,9 +1052,10 @@ namespace API
 
       // send the request to the server
       form.prepareSubmit(req);
+      
       std::ostream& ostr = session.sendRequest(req);
       form.write(ostr);
-      
+
       // get the answer from the server
       HTTPResponse response;
       std::istream & rs = session.receiveResponse(response);
@@ -1782,8 +1790,29 @@ bool ScriptRepositoryImpl::getProxyConfig(std::string& proxy_server, unsigned sh
         PROXYSERVER = proxy_option;
         PROXYPORT = 8080;
       }
-      g_log.notice() << "ScriptRepository proxy found. Host: " << PROXYSERVER << " Port: " << PROXYPORT << std::endl; 
+
+      try{
+        // test if the proxy is valid for the remote conection
+        Poco::URI uri(remote_url);
+        Poco::Net::HTTPClientSession session(uri.getHost(),uri.getPort());
+        session.setProxy(PROXYSERVER, PROXYPORT);
+        Poco::Net::HTTPRequest request(Poco::Net::HTTPRequest::HTTP_GET, "/",
+                                       Poco::Net::HTTPMessage::HTTP_1_1);
+        session.sendRequest(request);
+        Poco::Net::HTTPResponse response;
+        std::istream & rs = session.receiveResponse(response);
+        Poco::NullOutputStream null; 
+        Poco::StreamCopier::copyStream(rs,null);
+        g_log.notice() << "ScriptRepository proxy found. Host: " << PROXYSERVER << " Port: " << PROXYPORT << std::endl; 
+      }catch (Poco::Net::HostNotFoundException & ex){
+        g_log.information() << "ScriptRepository found that for this connection proxy can not be used. \n" 
+                            << ex.displayText() << std::endl; 
+        PROXYSERVER = "";
+        PROXYPORT = 0; 
+      }
+      
     }
+    
 #endif    
   }
   firstTime = false;
